@@ -100,12 +100,12 @@ void cb_done(Fl_Widget *widget, void *data) {
 int main(int argc, char** argv) {
 FILE *rcfile;
 Fl_Button *button[100];	 // This is the max under irremote
-char command[100][40];
+char command[100][80];   // Macros can be pretty large...
 char t[1024]; 		 // 80 characters my ASS!
                          // *grin* Ok!
 int nextButton = 0;
 int labelsize = 10;
- int show_toolbar = 1;
+int show_toolbar = 1;
 
 	if (!(rcfile = fopen("remote.ini", "r"))) 
 	{
@@ -113,7 +113,7 @@ int labelsize = 10;
 		exit(-1);
 	}
 
-	Fl_App_Window *btpwindow = WidgetFactory::new_window("BTP 6.2");
+	Fl_App_Window *btpwindow = WidgetFactory::new_window("BTP 6.3");
 	
 	Fl_Group *btpgroup = new Fl_Group(btpwindow->x(), btpwindow->y(), btpwindow->w(), btpwindow->h());
 	btpgroup->window()->resizable(btpgroup);
@@ -148,9 +148,19 @@ int labelsize = 10;
 			int height = atoi(strtok(NULL, ","));
 			char *label = strdup(strtok(NULL, ","));
 			char *remote = strdup(strtok(NULL, ","));
-			char *remoteCode = strdup(strtok(NULL, ",\n"));
+			char *remoteCode = strdup(strtok(NULL, "\n"));
 
-			sprintf(command[nextButton], "SEND_ONCE %s %s", remote, remoteCode);
+			//x,y,width,height,label,remote,remoteCode\n
+			//x,y,width,height,label,remote,remoteCode(\n|[,remoteCode|,remote:remoteCode]...\n)
+			//Phew...
+			//No, a dedicated "macro remote" would be simpler and more compatible.
+
+			if(strlen(remote)+1+strlen(remoteCode)>=80) { //Uh-hum, buffer overflows are nasty.
+			  puts("RemoteCode (macro?) too long!\n");
+			  exit(-1);
+			}
+			
+		        sprintf(command[nextButton], "%s %s", remote, remoteCode);
 
 			button[nextButton] = new Fl_Button(x, y, width, height, label);
 			button[nextButton]->labeltype(FL_SYMBOL_LABEL);
